==> connector-packaging-persnurse-3.15.1-net.zip: examples/be/ehealth/businessconnector/hubv3/helpers/HubConfigVitalink.cs <==
﻿﻿/*
 * Copyright (c) eHealth
 */
using System;
using be.fgov.ehealth.technicalconnector.tests.session;
using java.lang;
using java.util;
using be.ehealth.technicalconnector.idgenerator;
using be.ehealth.technicalconnector.utils;
using be.fgov.ehealth.hubservices.core.v3;
using NUnit.Framework;
using org.joda.time;
using be.ehealth.businessconnector.hubv3.builders;
using be.ehealth.businessconnector.hubv3.service;
using be.ehealth.businessconnector.hubv3.session;
using be.ehealth.businessconnector.hubv3.helpers;
using be.ehealth.technicalconnector.exception;
using be.fgov.ehealth.standards.kmehr.cd.v1;
using be.fgov.ehealth.standards.kmehr.id.v1;
using be.fgov.ehealth.standards.kmehr.schema.v1;
using be.ehealth.technicalconnector.config;
using be.ehealth.technicalconnector.config.impl;
using be.ehealth.technicalconnector.session;
using be.fgov.ehealth.technicalconnector.tests.utils;
using be.ehealth.business.intrahubcommons.exception;
using be.ehealth.business.kmehrcommons.helper;
using be.ehealth.businessconnector.testcommons;
using org.apache.commons.lang;

namespace be.ehealth.businessconnector.hubv3.helpers
{
	    public class HubConfigVitalink
		{
	        /*
	         * Patient Informations
	         */
             public static string PATIENT_NISS = "86013013502";
    
    		 public static string PATIENT_FIRSTNAME = "Zachary";

    		 public static string PATIENT_LASTNAME = "Wijmans";
    		 
        
             public static void initConfig() {
                ConfigFactory.getConfigValidator().getConfig().setProperty("endpoint.hubv3.intra", "https://vitalink-acpt.ehealth.fgov.be/vpmg/vitalink-gateway/IntraHubService");
                ConfigFactory.getConfigValidator().getConfig().setProperty("hubv3.id", "1990001916");
                ConfigFactory.getConfigValidator().getConfig().setProperty("hubv3.application", "VITALINKGATEWAY");
             }
	    }
}

==> connector-packaging-persnurse-4.6.0-net.zip: examples/be/ehealth/businessconnector/hubv3/helpers/HubConfigVitalink.cs <==
﻿﻿﻿/*
 * Copyright (c) eHealth
 */
using System;
using be.fgov.ehealth.technicalconnector.tests.session;
using java.lang;
using java.util;
using be.ehealth.technicalconnector.idgenerator;
using be.ehealth.technicalconnector.utils;
using be.fgov.ehealth.hubservices.core.v3;
using NUnit.Framework;
using org.joda.time;
using be.ehealth.businessconnector.hubv3.builders;
using be.ehealth.businessconnector.hubv3.service;
using be.ehealth.businessconnector.hubv3.session;
using be.ehealth.businessconnector.hubv3.helpers;
using be.ehealth.technicalconnector.exception;
using be.fgov.ehealth.standards.kmehr.cd.v1;
using be.fgov.ehealth.standards.kmehr.id.v1;
using be.fgov.ehealth.standards.kmehr.schema.v1;
using be.ehealth.technicalconnector.config;
using be.ehealth.technicalconnector.config.impl;
using be.ehealth.technicalconnector.session;
using be.fgov.ehealth.technicalconnector.tests.utils;
using be.ehealth.business.intrahubcommons.exception;
using be.ehealth.business.test.kmehrcommons.helper;
using be.ehealth.businessconnector.test.testcommons;
using org.apache.commons.lang;

namespace be.ehealth.businessconnector.hubv3.helpers
{
	    public class HubConfigVitalink
		{
	        /*
	         * Patient Informations
	         */
         	public static string PATIENT_NISS = "82051234978";
    	
         	public static string PATIENT_FIRSTNAME = "Hannes";

         	public static string PATIENT_LASTNAME = "De Clercq";
        
             public static void initConfig() {
                ConfigFactory.getConfigValidator().getConfig().setProperty("endpoint.hubv3.intra", "https://vitalink-acpt.ehealth.fgov.be/vpmg/vitalink-gateway/IntraHubService");
                ConfigFactory.getConfigValidator().getConfig().setProperty("hubv3.id", "1990001916");
                ConfigFactory.getConfigValidator().getConfig().setProperty("hubv3.application", "VITALINKGATEWAY");
             }
	    }
}
